/**
 * Copyright (c) 2021 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#pragma once
#include "../../libs.h"
#include "../../display/camera.h"
#include "../../display/font.h"
#include "../../display/shader.h"
#include "../../file/asset.h"
#include "../../ui/label.h"
#include "../../ui/breakpoint.h"

typedef struct {
  engine_t engine;
  shader_t shader;
  texture_t texture;
  font_t font;
} sandboxscene_t;

/**
 * Initialize the sandbox scene test game.
 * 
 * @param game Game to initialize.
 * @param engine Engine to use during init.
 * @return True if successful, otherwise false.
 */
bool sandboxSceneInit(sandboxscene_t *game);

/**
 * Update a sandbox scene.
 * 
 * @param game Game to update.
 * @param engine Engine to use when updating.
 */
void sandboxSceneUpdate(sandboxscene_t *game);

/**
 * Dispose a previously created scene game.
 * 
 * @param game Game to dispose.
 */
void sandboxSceneDispose(sandboxscene_t *game);